@@ -151,6 +151,7 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
     }
     char val[1024];
     size_t length = 1024;
+    
 
     int err = grib_get_string(handle_, key.c_str(), val, &length);
 
@@ -158,12 +159,15 @@ string GribDecoder::getstring(const string& key, bool warnIfKeyAbsent, bool cach
     {
         if (warnIfKeyAbsent)
         {
+            
             MagLog::warning() << "Grib API: can not find key [" << key << "]  - "<< grib_get_error_message(err) <<"\n";
+             
         }
         return "";
     }
     if ( cache )
         sKeys_.insert(make_pair(key, val));
+    
     return string(val);
 }
 
@@ -261,7 +265,7 @@ void GribDecoder::scale(const string& metadata, double& scaling, double& offset)
 void GribDecoder::read(Matrix **matrix, Matrix** matrix2)
 {
 
-    if ( handle_ <=0 ) {
+    if ( !handle_ ) {
         *matrix = 0;
         return;
     }
@@ -296,12 +300,11 @@ void GribDecoder::read(Matrix **matrix, Matrix** matrix2)
 
 void GribDecoder::read(Matrix **matrix, const Transformation&  transformation)
 {
-    if ( handle_ <=0 ) {
+    if ( !handle_  ) {
         *matrix = 0;
         return;
     }
-    long repres;
-    grib_get_long(handle_,"dataRepresentationType",&repres);
+    
     const string representation = getString("typeOfGrid");
 
     try {
@@ -754,7 +757,7 @@ grib_handle*  GribDecoder::open(grib_handle* grib, bool sendmsg)
 
     handle_ = (*address_mode_)(0, file, grib_field_position_);
 
-    if (handle_<=0 )
+    if ( !handle_ )
     {
         if (sendmsg) {
             MagLog::error() << "can not access position [" << grib_field_position_<<" in " << file_name_ << "]" << std::endl;
@@ -965,12 +968,10 @@ bool  GribLoop::hasMore()
             // case 1 dimension= 1 and loop on all the fields!
             int error;
             grib_handle* handle = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle <=0)
+            if ( !handle )
                 return false;
             currentgrib_ = new GribEntryDecoder(handle);
-
             currentgrib_->set(*this, counter_++);
-
             gribs_.push_back(currentgrib_);
         }
         else {
@@ -980,7 +981,7 @@ bool  GribLoop::hasMore()
 
             grib_handle* handle =  (*address_mode_)(0, file_, *currentPos_);
             currentPos_++;
-            if (handle <=0)
+            if (!handle)
                 return false;
             currentgrib_ = new GribEntryDecoder(handle);
             currentgrib_->set(*this, counter_++);
@@ -996,9 +997,9 @@ bool  GribLoop::hasMore()
             // case 2 Dimension = 2 and loop on all the field!
             int error;
             grib_handle* handle1 = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle1 <=0)  return false;
+            if (!handle1)  return false;
             grib_handle* handle2 = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle2 <=0)  return false;
+            if (!handle2)  return false;
             currentgrib_ = new GribEntryDecoder(handle1, handle2);
             currentgrib_->set(*this, counter_++);
             gribs_.push_back(currentgrib_);
@@ -1017,9 +1018,9 @@ bool  GribLoop::hasMore()
 
             grib_handle* handle1 =  (*address_mode_)(0, file_, *dim1);
             grib_handle* handle2 =  (*address_mode_)(0, file_, *dim2);
-            if ( handle1 <=0 )
+            if ( !handle1 )
                 return false;
-            if ( handle2 <=0 )
+            if ( !handle2 )
                 return false;
             currentgrib_ = new GribEntryDecoder(handle1, handle2);
             currentgrib_->set(*this, counter_++);
@@ -1036,11 +1037,11 @@ bool  GribLoop::hasMore()
             // case 2 Dimension = 2 and loop on all the field!
             int error;
             grib_handle* handle1 = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle1 <=0)  return false;
+            if ( !handle1 )  return false;
             grib_handle* handle2 = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle2 <=0)  return false;
+            if ( !handle2 )  return false;
             grib_handle* handle3 = grib_handle_new_from_file(0, file_, &error) ;
-            if (handle3 <=0)  return false;
+            if ( !handle3)  return false;
             currentgrib_ = new GribEntryDecoder(handle1, handle2, handle3);
             currentgrib_->set(*this, counter_++);
             gribs_.push_back(currentgrib_);
@@ -1064,11 +1065,11 @@ bool  GribLoop::hasMore()
             grib_handle* handle2 =  (*address_mode_)(0, file_, *dim2);
             grib_handle* handle3 =  (*address_mode_)(0, file_, *dim3);
 
-            if ( handle1 <=0 )
+            if ( !handle1 )
                 return false;
-            if ( handle2 <=0 )
+            if ( !handle2 )
                 return false;
-            if ( handle3 <=0 )
+            if ( !handle3 )
                 return false;
             currentgrib_ = new GribEntryDecoder(handle1, handle2, handle3);
             currentgrib_->set(*this, counter_++);
@@ -1765,14 +1766,25 @@ void GribDecoder::decode(const Transformation& transformation)
     to_ =  DateTime(helper.get("grib"+id_, "end-date"));
 }
 
+//// RV MF ////
+void GribDecoder::decode1D()
+{
+    if (matrix_) return;
+    field_ = open(field_);
+    read(&matrix_);
+}
+//// RV MF ////
+
 void GribDecoder::decode()
 {
 
     if ( dimension_ == 1) {
-        if (matrix_) return;
-        field_ = open(field_);
-        read(&matrix_);
-        if (!matrix_) return;
+// RV MF
+//      if (matrix_) return;
+//      field_ = open(field_);
+//      read(&matrix_);
+//      if (!matrix_) return;
+        decode1D();
     }
     else {
         decode2D();
@@ -2067,7 +2079,7 @@ public:
         long hour = grib.getLong("hour");
         long mn =  grib.getLong("minute");
         string x = grib.getString("dataDate");
-        cout << x << endl;
+        
 
         MagDate part1 = MagDate(date);
         MagTime part2 = MagTime(hour, mn, 0);
@@ -2128,14 +2140,25 @@ public:
     {
 
         ostringstream out;
-        long istep = grib.getLong("startStep");
+        long startstep = grib.getLong("startStep"); 
+        long endstep = grib.getLong("endStep");
 
+        
+
+        if ( startstep != endstep ) {
+            ostringstream step;
+            step << "from t+" << startstep << " to t+" << endstep;
+            title.back() += step.str();
+            return;
+        }
+         
 
         ostringstream step;
-        step << istep;
+        step << startstep;
         string format = field.attribute("format", "t+%s");
         out << SimpleStringFormat(step.str(), format);
         title.back() += out.str();
+        
     }
 };
 
@@ -2303,6 +2326,7 @@ public:
             names[54] = "METEOSAT-7";
             names[55] = "METEOSAT-8";
             names[57] = "METEOSAT-10";
+            names[70] = "METEOSAT-11";
             names[172] = "MTSAT-2";
             names[257] = "GOES-13";
             names[259] = "GOES-15";
@@ -2350,6 +2374,15 @@ public:
             l57[9] = "IR 10-8";
             l57[10] = "IR 12-0";
             channels[57] = l57;
+            map<long, string>  l70;
+            l70[1] = "VIS 0-6";
+            l70[4] = "IR 3-9";
+            l70[5] = "WV 6-2";
+            l70[6] = "WV 7-3";
+            l70[8] = "IR 9-7";
+            l70[9] = "IR 10-8";
+            l70[10] = "IR 12-0";
+            channels[70] = l70;
             map<long, string>  l172;
             l172[2] = "IR 10-8";
             l172[4] = "WV 6-8";
